@@ -15,80 +15,35 @@ class Parser(object):
                        allow_null=True,
                        screen_width=180,
                        max_parse_time=5,
-                       max_memory=128000000,
                        disjunct_cost=10000,
                        max_sentence_length=170):
         locale.setlocale(locale.LC_ALL,"en_US.UTF-8")
-        
-        #We need to retain all these options cause we will
-        #recreate the parse_options if the parser starts failing
-        self.verbosity = verbosity
-        self.linkage_limit = linkage_limit
-        self.min_null_count = min_null_count
-        self.max_null_count = max_null_count
-        self.null_block = null_block
-        self.islands_ok = islands_ok
-        self.short_length = short_length
-        self.all_short_connectors = all_short_connectors
-        self.display_walls = display_walls
-        self.screen_width = screen_width
-        self.max_parse_time = max_parse_time
-        self.max_memory = max_memory
-        self.disjunct_cost = disjunct_cost
-        self.max_sentence_length = max_sentence_length
-        self.allow_null = allow_null
-        
-        self._create_parse_options()
         self.dictionary = Dictionary("en")
-
-    def _create_parse_options(self):
-        self.parse_options = ParseOptions(verbosity=self.verbosity,
-                                          linkage_limit=self.linkage_limit,
-                                          min_null_count=self.min_null_count,
-                                          max_null_count=self.max_null_count,
-                                          null_block=self.null_block,
-                                          islands_ok=self.islands_ok,
-                                          short_length=self.short_length,
-                                          display_walls=self.display_walls,
-                                          allow_null=self.allow_null,
-                                          screen_width=self.screen_width,
-                                          max_parse_time=self.max_parse_time,
-                                          max_memory=self.max_memory,
-                                          disjunct_cost=self.disjunct_cost,
-                                          max_sentence_length=self.max_sentence_length)
+        self.parse_options = ParseOptions(verbosity=verbosity,
+                                          linkage_limit=linkage_limit,
+                                          min_null_count=min_null_count,
+                                          max_null_count=max_null_count,
+                                          null_block=null_block,
+                                          islands_ok=islands_ok,
+                                          short_length=short_length,
+                                          display_walls=display_walls,
+                                          allow_null=allow_null,
+                                          screen_width=screen_width,
+                                          max_parse_time=max_parse_time,
+                                          disjunct_cost=disjunct_cost,
+                                          max_sentence_length=max_sentence_length)
         
         
     def parse_sent(self, txt):
         sent = clg.sentence_create(txt,self.dictionary._dict)
         n = clg.sentence_parse(sent, self.parse_options._po)
-        #This is ugly, but the parser sometiems starts failing on parses.
-        #if it fails, recreate parse_options one time and try again. This will correct the issue.
-        #If the sentence truly cannot be parsed, then it'll fail on the second time.
-        if n == 0:
-            self._create_parse_options()
-            n = clg.sentence_parse(sent, self.parse_options._po)
         if n > 0:
             linkages = [Linkage.create_from_sentence(i,sent, self.parse_options._po) for i in range(n)]
         else:
-            linkages = None
+            linkages = []
         clg.sentence_delete(sent)
-        #linkgrammar will start to poop its pants if its 'resources' are exhausted.
-        #This is a little ugly to check each time but it seems to be a cheap operation.
-        #If the resources are exhausted, then reset them.
-        #Extra note: apparently resetting them was not enough. If you kept parsing
-        #the same sentence over and over, eventually the parser were stop returning
-        #parses. I found that deleting and reinstantiating the parse_options corrected
-        #this issue.
-        if clg.parse_options_resources_exhausted(self.parse_options._po):
-            clg.parse_options_reset_resources(self.parse_options._po)
-            del self.parse_options
-            self._create_parse_options()
         return linkages
-    
-    def __del__(self):
-        del self.parse_options
-        del self.dictionary
-
+   
     @property
     def version(self):
         return clg.linkgrammar_get_version()
@@ -106,7 +61,6 @@ class ParseOptions(object):
                        allow_null=True,
                        screen_width=180,
                        max_parse_time=-1,
-                       max_memory=128000000,
                        disjunct_cost=10000,
                        max_sentence_length=170):
     
@@ -123,7 +77,6 @@ class ParseOptions(object):
         self.display_walls = display_walls
         self.screen_width = screen_width
         self.max_parse_time = max_parse_time
-        self.max_memory = max_memory
         self.disjunct_cost = disjunct_cost
         self.max_sentence_length = max_sentence_length
         self.allow_null = allow_null
@@ -252,19 +205,6 @@ class ParseOptions(object):
         return locals()
     islands_ok = property(**islands_ok())
             
-    def max_memory():
-        doc = "Determines the maximum memory allowed during parsing. This is used just as max_parse_time is, so that the parsing process is terminated as quickly as possible after the total memory (including that allocated to all dictionaries, etc.) exceeds the maximum allowed."
-        def fget(self):
-            return clg.parse_options_get_max_memory(self._po)
-        def fset(self, value):
-            if not isinstance(value, int):
-                raise TypeError("max_memory must be set to an integer")
-            if value < 0:
-                raise ValueError("max_memory must be positive")
-            clg.parse_options_set_max_memory(self._po, value)
-        return locals()
-    max_memory = property(**max_memory())
-            
     def max_parse_time():
         doc = "Determines the approximate maximum time (in seconds) that parsing is allowed to take. The way it works is that after this time has expired, the parsing process is artificially forced to complete quickly by pretending that no further solutions (entries in the hash table) can be constructed. The actual parsing time might be slightly longer."
         def fget(self):
@@ -434,4 +374,4 @@ class ConstituentNode(object):
             return "<%s>" % self.type
 
     def __eq__(self, other):
-        return self.type == other.type and self.words == other.words
\ No newline at end of file
+        return self.type == other.type and self.words == other.words
